@@ -9,7 +9,7 @@ class TestMissing(unittest.TestCase):
     def setUp(self) -> Graph:
 
         def get_index(counter=[0]):
-            index_list = [True, False, True, False, True]
+            index_list = [False, True, False, True, False]
             counter[0] += 1
             return index_list[counter[0] - 1]
 
@@ -26,7 +26,7 @@ class TestMissing(unittest.TestCase):
 
     def test_missing(self):
         data = self.setUp().simulate(5)
-        self.assertEqual([True, False, True, False, True], data["i"])
+        self.assertEqual([False, True, False, True, False], data["i"])
         self.assertEqual([1, 2, 3, 4, 5], data["toBeMissed"])
         self.assertEqual([1, 'NaN', 3, 'NaN', 5], data['M1'])
 
